siri_model_summer
and siri_model_winter functions.This is an internal function that checks inputs to the disease_simulator
function to make sure they are valid, and sets default values for needed
inputs if their values are not supplied. The possible inputs for this
function are the same as the possible inputs to the disease_simulator
function.
check_aspatial_siri_inputs(inputs)A list identical to the inputs (if there are no errors.)
A nested list with named elements:
replicatesNumber of replicate simulation runs.
time_stepsNumber of simulation time steps.
populationsNumber of populations.
stagesNumber of life cycle stages.
compartmentsNumber of disease compartments (e.g., 3 for a SIR model).
abundance_thresholdA quasi-extinction threshold at which a population becomes extinct.
mortalityA vector of mortality rates, one for each combination of stages and compartments.
mortality_unitA vector indicating whether mortality rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
fecundityA vector of fecundity rates, one for each combination of stages and compartments for which fecundity applies.
fecundity_unitA vector indicating whether fecundity rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
fecundity_maskA vector indicating which stages and compartments reproduce.
transmissionA vector of transmission rates, one for each
combination of stages and compartment for which transmission applies (see
transmission_mask below.
transmission_unitA vector indicating whether mortality rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
transmission_maskA vector indicating which stages and compartments are subject to transmission (i.e., classes susceptible to infection.)
recoveryA vector of recovery rates, one for each
combination of stages and compartment for which recovery applies (see
recovery_mask below.)
recovery_unitA vector indicating whether mortality rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
recovery_maskA vector indicating which compartments are subject to recovery (i.e., infected classes that can recover.)
rSimulation replicate.
tmSimulation time step.
carrying_capacityArray of carrying capacity values for each population at time step.
breeding_season_lengthArray of breeding season lengths in days for each population at time step.
segment_abundanceMatrix of (current) abundance for each stage-compartment combo (rows) and population (columns) at time step.
occupied_indicesArray of indices for populations occupied at (current) time step.
simulatorpoems::SimulatorReference object with
dynamically accessible attached and results lists.
additional attributesAdditional attributes when the transformation is optionally nested in a list.