Learn R Programming

epizootic (version 2.0.0)

epizootic-package: epizootic: Spatially Explicit Population Models of Disease Transmission in Wildlife

Description

This extension of the pattern-oriented modeling framework of the 'poems' package provides a collection of modules and functions customized for modeling disease transmission on a population scale in a spatiotemporally explicit manner. This includes seasonal time steps, dispersal functions that track disease state of dispersers, results objects that store disease states, and a population simulator that includes disease dynamics.

Arguments

Author

Maintainer: July Pilowsky pilowskyj@caryinstitute.org (ORCID)

Other contributors:

  • National Science Foundation Biology Integration Institute 2213854 [funder]

See Also