Simulate a Mycoplasma gallisepticum outbreak during the non-breeding season day-by-day in a population of house finches (Haemorhous mexicanus). Uses a SIRI model (Susceptible-Infected 1- Recovered-Infected 2+) and includes demographic stochasticity in fecundity, mortality, and infection.
siri_model_winter(inputs)An abundance matrix with populations columns and
stages*compartments rows, updated from the segment_abundance input in
inputs according to demography and disease dynamics.
A nested list with named elements:
replicatesNumber of replicate simulation runs.
time_stepsNumber of simulation time steps.
populationsNumber of populations.
stagesNumber of life cycle stages.
compartmentsNumber of disease compartments (e.g., 3 for a SIR model).
abundance_thresholdA quasi-extinction threshold below which a population becomes extinct.
mortalityA vector of mortality rates, one for each combination of stages and compartments.
mortality_unitA vector indicating whether mortality rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
fecundityA vector of fecundity rates, one for each combination of stages and compartments for which fecundity applies.
fecundity_unitA vector indicating whether fecundity rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
fecundity_maskA vector indicating which stages and compartments reproduce.
transmissionA vector of transmission rates, one for each
combination of stages and compartment for which transmission applies (see
transmission_mask below.
transmission_unitA vector indicating whether mortality rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
transmission_maskA vector indicating which stages and compartments are subject to transmission (i.e., classes susceptible to infection.)
recoveryA vector of recovery rates, one for each
combination of stages and compartment for which recovery applies (see
recovery_mask below.)
recovery_unitA vector indicating whether mortality rates are daily or seasonal. 1 indicates seasonal, 0 indicates daily.
recovery_maskA vector indicating which compartments are subject to recovery (i.e., infected classes that can recover.)
rSimulation replicate.
tmSimulation time step.
carrying_capacityArray of carrying capacity values for each population at time step.
breeding_season_lengthArray of breeding season lengths in days for each population at time step.
segment_abundanceMatrix of (current) abundance for each stage-compartment combo (rows) and population (columns) at time step.
occupied_indicesArray of indices for populations occupied at (current) time step.
simulatorpoems::SimulatorReference object with
dynamically accessible attached and results lists.
additional attributesAdditional attributes when the transformation is optionally nested in a list.
The function can also handle the case in which there are no infected individuals. The principal difference between this function and the one for simulating an outbreak in the breeding season is that this one does not include fecundity.